Installation and Configuration
==============================

Install the Plone Embedding Add-On
----------------------------------

You can install the Add-On like any other Plone Add-On: click on your username in the *personal tools menu* and select **Site Setup**.
Next, click the **Add-Ons** item in the *Plone Configuration* section.
You should see an item called **Propertyshelf MLS**.

.. image:: ../_images/setup_select_add_on.png


Change the default MLS Configuration
------------------------------------

Before you can start embedding listings into your Plone site you have to connect to the MLS.
But don't worry, this only needs to be done once.
Please ask your MLS Administrator for your API Key.

To change the settings for your MLS embedding go to the **Site Setup** and select the Add-On configuration **Propertyshelf Base Settings**.
In the form, enter your MLS connection settings.

.. image:: ../_images/configure_base_settings.png


Changing the MLS configuration for a particular folder
------------------------------------------------------


Overriding the point of contact
-------------------------------


Overriding the contact information for a particular folder
----------------------------------------------------------
